@@ -1,2 +1,2 @@
-from configur.config import Settings
+from configur.settings import Settings
 from configur.logging_config import init_logging
